fused
A project that aims to fuse the concurrency models of OTP and Javascript to allow the careful user to write concurrent code that runs on both the otp backend and the gleam backend
Warning: this is still a work in progress and the API is subject to change
gleam add fused@1
import fused
pub fn main() -> Nil {
// TODO: An example of the project in use
}
Further documentation can be found at https://hexdocs.pm/fused.
Development
gleam run # Run the project
gleam test # Run the tests